bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.broadcasting_multiplier
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGamma.broadcasting_multiplier